from django.conf import settings
from django.utils.html import format_html

class Icon(object):

    def __init__(self, id):
        self.id = id

    def as_html(self):
        if not self.id:
            return ''

        prefix = getattr(settings, 'FONTAWESOME_PREFIX', 'fa')
        return format_html('<i class="{0} {0}-{1}"></i>', prefix, self.id)

    def __str__(self):
        return self.id

    def __unicode__(self):
        return str(self)


from django import template

register = template.Library()

@register.simple_tag
def fontawesome_icon(icon, large=False, fixed=False, spin=False):

    return '<i class="fa fa-{icon} {large} {fixed} {spin}"></i>'.format(
        icon=icon,
        large='fa-lg' if large is True else '',
        fixed='fa-fw' if fixed else '',
        spin='fa-spin' if spin else '',
    )



import os
import yaml

PATH = os.path.join(os.path.dirname(__file__), 'icons.yml')

def get_icon_choices():

    CHOICES = []

    with open(PATH) as f:
        icons = yaml.load(f)

        for icon in icons.get('icons'):
            CHOICES.append((
                icon.get('id'),
                icon.get('name')
            ))

    return CHOICES


from django.db import models
from django.utils.translation import ugettext as _

from . import Icon
from forms import IconFormField

class IconField(models.Field):

    description = _('A fontawesome icon field')
    __metaclass__ = models.SubfieldBase

    def __init__(self, *args, **kwargs):
        kwargs['max_length'] = 60
        super(IconField, self).__init__(*args, **kwargs)

    def get_internal_type(self):
        return 'CharField'

    def to_python(self, value):
        if not value or value == 'None':
            return None

        if isinstance(value, Icon):
            return value

        # default => string
        return Icon(id=value)

    def get_prep_value(self, value):
        return str(value)

    def formfield(self, **kwargs):
        defaults = {
            'form_class':IconFormField,
            #'choices_form_class':IconFormField
        }

        defaults.update(kwargs)
        return super(IconField, self).formfield(**defaults)